
#line 3 "sbr/dtimep.c"

#define  YY_INT_ALIGNED short int

/* A lexical scanner generated by flex */

#define FLEX_SCANNER
#define YY_FLEX_MAJOR_VERSION 2
#define YY_FLEX_MINOR_VERSION 5
#define YY_FLEX_SUBMINOR_VERSION 35
#if YY_FLEX_SUBMINOR_VERSION > 0
#define FLEX_BETA
#endif

/* First, we deal with  platform-specific or compiler-specific issues. */

/* begin standard C headers. */
#include <stdio.h>
#include <string.h>
#include <errno.h>
#include <stdlib.h>

/* end standard C headers. */

/* flex integer type definitions */

#ifndef FLEXINT_H
#define FLEXINT_H

/* C99 systems have <inttypes.h>. Non-C99 systems may or may not. */

#if defined (__STDC_VERSION__) && __STDC_VERSION__ >= 199901L

/* C99 says to define __STDC_LIMIT_MACROS before including stdint.h,
 * if you want the limit (max/min) macros for int types. 
 */
#ifndef __STDC_LIMIT_MACROS
#define __STDC_LIMIT_MACROS 1
#endif

#include <inttypes.h>
typedef int8_t flex_int8_t;
typedef uint8_t flex_uint8_t;
typedef int16_t flex_int16_t;
typedef uint16_t flex_uint16_t;
typedef int32_t flex_int32_t;
typedef uint32_t flex_uint32_t;
typedef uint64_t flex_uint64_t;
#else
typedef signed char flex_int8_t;
typedef short int flex_int16_t;
typedef int flex_int32_t;
typedef unsigned char flex_uint8_t; 
typedef unsigned short int flex_uint16_t;
typedef unsigned int flex_uint32_t;
#endif /* ! C99 */

/* Limits of integral types. */
#ifndef INT8_MIN
#define INT8_MIN               (-128)
#endif
#ifndef INT16_MIN
#define INT16_MIN              (-32767-1)
#endif
#ifndef INT32_MIN
#define INT32_MIN              (-2147483647-1)
#endif
#ifndef INT8_MAX
#define INT8_MAX               (127)
#endif
#ifndef INT16_MAX
#define INT16_MAX              (32767)
#endif
#ifndef INT32_MAX
#define INT32_MAX              (2147483647)
#endif
#ifndef UINT8_MAX
#define UINT8_MAX              (255U)
#endif
#ifndef UINT16_MAX
#define UINT16_MAX             (65535U)
#endif
#ifndef UINT32_MAX
#define UINT32_MAX             (4294967295U)
#endif

#endif /* ! FLEXINT_H */

#ifdef __cplusplus

/* The "const" storage-class-modifier is valid. */
#define YY_USE_CONST

#else	/* ! __cplusplus */

/* C99 requires __STDC__ to be defined as 1. */
#if defined (__STDC__)

#define YY_USE_CONST

#endif	/* defined (__STDC__) */
#endif	/* ! __cplusplus */

#ifdef YY_USE_CONST
#define yyconst const
#else
#define yyconst
#endif

/* Returned upon end-of-file. */
#define YY_NULL 0

/* Promotes a possibly negative, possibly signed char to an unsigned
 * integer for use as an array index.  If the signed char is negative,
 * we want to instead treat it as an 8-bit unsigned char, hence the
 * double cast.
 */
#define YY_SC_TO_UI(c) ((unsigned int) (unsigned char) c)

/* Enter a start condition.  This macro really ought to take a parameter,
 * but we do it the disgusting crufty way forced on us by the ()-less
 * definition of BEGIN.
 */
#define BEGIN (yy_start) = 1 + 2 *

/* Translate the current start state into a value that can be later handed
 * to BEGIN to return to the state.  The YYSTATE alias is for lex
 * compatibility.
 */
#define YY_START (((yy_start) - 1) / 2)
#define YYSTATE YY_START

/* Action number for EOF rule of a given start state. */
#define YY_STATE_EOF(state) (YY_END_OF_BUFFER + state + 1)

/* Special action meaning "start processing a new file". */
#define YY_NEW_FILE yyrestart(yyin  )

#define YY_END_OF_BUFFER_CHAR 0

/* Size of default input buffer. */
#ifndef YY_BUF_SIZE
#define YY_BUF_SIZE 16384
#endif

/* The state buf must be large enough to hold one state per character in the main buffer.
 */
#define YY_STATE_BUF_SIZE   ((YY_BUF_SIZE + 2) * sizeof(yy_state_type))

#ifndef YY_TYPEDEF_YY_BUFFER_STATE
#define YY_TYPEDEF_YY_BUFFER_STATE
typedef struct yy_buffer_state *YY_BUFFER_STATE;
#endif

#ifndef YY_TYPEDEF_YY_SIZE_T
#define YY_TYPEDEF_YY_SIZE_T
typedef size_t yy_size_t;
#endif

extern yy_size_t yyleng;

extern FILE *yyin, *yyout;

#define EOB_ACT_CONTINUE_SCAN 0
#define EOB_ACT_END_OF_FILE 1
#define EOB_ACT_LAST_MATCH 2

    #define YY_LESS_LINENO(n)
    
/* Return all but the first "n" matched characters back to the input stream. */
#define yyless(n) \
	do \
		{ \
		/* Undo effects of setting up yytext. */ \
        int yyless_macro_arg = (n); \
        YY_LESS_LINENO(yyless_macro_arg);\
		*yy_cp = (yy_hold_char); \
		YY_RESTORE_YY_MORE_OFFSET \
		(yy_c_buf_p) = yy_cp = yy_bp + yyless_macro_arg - YY_MORE_ADJ; \
		YY_DO_BEFORE_ACTION; /* set up yytext again */ \
		} \
	while ( 0 )

#define unput(c) yyunput( c, (yytext_ptr)  )

#ifndef YY_STRUCT_YY_BUFFER_STATE
#define YY_STRUCT_YY_BUFFER_STATE
struct yy_buffer_state
	{
	FILE *yy_input_file;

	char *yy_ch_buf;		/* input buffer */
	char *yy_buf_pos;		/* current position in input buffer */

	/* Size of input buffer in bytes, not including room for EOB
	 * characters.
	 */
	yy_size_t yy_buf_size;

	/* Number of characters read into yy_ch_buf, not including EOB
	 * characters.
	 */
	yy_size_t yy_n_chars;

	/* Whether we "own" the buffer - i.e., we know we created it,
	 * and can realloc() it to grow it, and should free() it to
	 * delete it.
	 */
	int yy_is_our_buffer;

	/* Whether this is an "interactive" input source; if so, and
	 * if we're using stdio for input, then we want to use getc()
	 * instead of fread(), to make sure we stop fetching input after
	 * each newline.
	 */
	int yy_is_interactive;

	/* Whether we're considered to be at the beginning of a line.
	 * If so, '^' rules will be active on the next match, otherwise
	 * not.
	 */
	int yy_at_bol;

    int yy_bs_lineno; /**< The line count. */
    int yy_bs_column; /**< The column count. */
    
	/* Whether to try to fill the input buffer when we reach the
	 * end of it.
	 */
	int yy_fill_buffer;

	int yy_buffer_status;

#define YY_BUFFER_NEW 0
#define YY_BUFFER_NORMAL 1
	/* When an EOF's been seen but there's still some text to process
	 * then we mark the buffer as YY_EOF_PENDING, to indicate that we
	 * shouldn't try reading from the input source any more.  We might
	 * still have a bunch of tokens to match, though, because of
	 * possible backing-up.
	 *
	 * When we actually see the EOF, we change the status to "new"
	 * (via yyrestart()), so that the user can continue scanning by
	 * just pointing yyin at a new input file.
	 */
#define YY_BUFFER_EOF_PENDING 2

	};
#endif /* !YY_STRUCT_YY_BUFFER_STATE */

/* Stack of input buffers. */
static size_t yy_buffer_stack_top = 0; /**< index of top of stack. */
static size_t yy_buffer_stack_max = 0; /**< capacity of stack. */
static YY_BUFFER_STATE * yy_buffer_stack = 0; /**< Stack as an array. */

/* We provide macros for accessing buffer states in case in the
 * future we want to put the buffer states in a more general
 * "scanner state".
 *
 * Returns the top of the stack, or NULL.
 */
#define YY_CURRENT_BUFFER ( (yy_buffer_stack) \
                          ? (yy_buffer_stack)[(yy_buffer_stack_top)] \
                          : NULL)

/* Same as previous macro, but useful when we know that the buffer stack is not
 * NULL or when we need an lvalue. For internal use only.
 */
#define YY_CURRENT_BUFFER_LVALUE (yy_buffer_stack)[(yy_buffer_stack_top)]

/* yy_hold_char holds the character lost when yytext is formed. */
static char yy_hold_char;
static yy_size_t yy_n_chars;		/* number of characters read into yy_ch_buf */
yy_size_t yyleng;

/* Points to current character in buffer. */
static char *yy_c_buf_p = (char *) 0;
static int yy_init = 0;		/* whether we need to initialize */
static int yy_start = 0;	/* start state number */

/* Flag which is used to allow yywrap()'s to do buffer switches
 * instead of setting up a fresh yyin.  A bit of a hack ...
 */
static int yy_did_buffer_switch_on_eof;

void yyrestart (FILE *input_file  );
void yy_switch_to_buffer (YY_BUFFER_STATE new_buffer  );
YY_BUFFER_STATE yy_create_buffer (FILE *file,int size  );
void yy_delete_buffer (YY_BUFFER_STATE b  );
void yy_flush_buffer (YY_BUFFER_STATE b  );
void yypush_buffer_state (YY_BUFFER_STATE new_buffer  );
void yypop_buffer_state (void );

static void yyensure_buffer_stack (void );
static void yy_load_buffer_state (void );
static void yy_init_buffer (YY_BUFFER_STATE b,FILE *file  );

#define YY_FLUSH_BUFFER yy_flush_buffer(YY_CURRENT_BUFFER )

YY_BUFFER_STATE yy_scan_buffer (char *base,yy_size_t size  );
YY_BUFFER_STATE yy_scan_string (yyconst char *yy_str  );
YY_BUFFER_STATE yy_scan_bytes (yyconst char *bytes,yy_size_t len  );

void *yyalloc (yy_size_t  );
void *yyrealloc (void *,yy_size_t  );
void yyfree (void *  );

#define yy_new_buffer yy_create_buffer

#define yy_set_interactive(is_interactive) \
	{ \
	if ( ! YY_CURRENT_BUFFER ){ \
        yyensure_buffer_stack (); \
		YY_CURRENT_BUFFER_LVALUE =    \
            yy_create_buffer(yyin,YY_BUF_SIZE ); \
	} \
	YY_CURRENT_BUFFER_LVALUE->yy_is_interactive = is_interactive; \
	}

#define yy_set_bol(at_bol) \
	{ \
	if ( ! YY_CURRENT_BUFFER ){\
        yyensure_buffer_stack (); \
		YY_CURRENT_BUFFER_LVALUE =    \
            yy_create_buffer(yyin,YY_BUF_SIZE ); \
	} \
	YY_CURRENT_BUFFER_LVALUE->yy_at_bol = at_bol; \
	}

#define YY_AT_BOL() (YY_CURRENT_BUFFER_LVALUE->yy_at_bol)

/* Begin user sect3 */

typedef unsigned char YY_CHAR;

FILE *yyin = (FILE *) 0, *yyout = (FILE *) 0;

typedef int yy_state_type;

extern int yylineno;

int yylineno = 1;

extern char *yytext;
#define yytext_ptr yytext

static yy_state_type yy_get_previous_state (void );
static yy_state_type yy_try_NUL_trans (yy_state_type current_state  );
static int yy_get_next_buffer (void );
static void yy_fatal_error (yyconst char msg[]  );

/* Done after the current pattern has been matched and before the
 * corresponding action - sets up yytext.
 */
#define YY_DO_BEFORE_ACTION \
	(yytext_ptr) = yy_bp; \
	yyleng = (yy_size_t) (yy_cp - yy_bp); \
	(yy_hold_char) = *yy_cp; \
	*yy_cp = '\0'; \
	(yy_c_buf_p) = yy_cp;

#define YY_NUM_RULES 30
#define YY_END_OF_BUFFER 31
/* This struct is not used in this scanner,
   but its presence is necessary. */
struct yy_trans_info
	{
	flex_int32_t yy_verify;
	flex_int32_t yy_nxt;
	};
static yyconst flex_int16_t yy_accept[571] =
    {   0,
        0,    0,   31,   29,   29,   29,   29,   29,   29,   29,
       29,   29,   29,   29,   29,   29,   29,   29,   29,    0,
        0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
        0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
        0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
        0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
        0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
        0,    0,    0,    0,    0,   14,    0,    0,    0,    0,
        0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
        0,    0,    0,    0,    0,    0,    0,    0,    0,    0,

        0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
        0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
        0,    0,   26,   25,   19,   18,   17,   16,   15,   28,
       27,   21,   20,   24,   23,   22,   12,   13,    0,    0,
        0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
        0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
        0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
        0,    0,    0,   12,   13,    0,    0,    0,    0,    0,
        0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
        0,    0,    0,    0,    0,    0,    0,    0,    0,    0,

        0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
        0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
        0,    0,    0,    0,    0,    0,    0,    0,    0,    9,
        9,    0,    0,    0,    0,    0,    0,    0,    0,    0,
        0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
        0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
        0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
        0,    0,    0,    0,    0,    9,    0,    0,    0,    0,
        0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
        0,    0,    0,    0,    0,    0,    0,    0,    0,    0,

        0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
        0,    0,    0,    0,    0,    0,    0,    0,    0,    9,
        7,    7,    0,    0,    0,    0,    0,    0,    0,    0,
        0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
        0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
        0,   10,   11,    0,    0,    0,    0,    0,    0,    0,
        0,    0,    0,    0,    0,    0,    7,    0,    0,    0,
        0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
        0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
        0,    0,    0,    0,    0,    0,    0,    0,    0,    0,

        0,    0,    0,    7,    0,    0,    0,    0,    0,    0,
        0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
        0,    0,    0,    0,    0,    0,    0,    0,    0,    8,
        0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
        0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
        0,    0,    0,    0,    0,    0,    0,    0,    6,    6,
        6,    6,    6,    6,    6,    0,    0,    0,    0,    0,
        0,    0,    0,    0,    5,    0,    5,    0,    0,    0,
        0,    0,    0,    3,    0,    0,    0,    0,    0,    0,
        0,    0,    0,    0,    0,    0,    0,    0,    0,    0,

        0,    0,    0,    0,    5,    5,    5,    0,    0,    8,
        0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
        0,    0,    0,    0,    5,    0,    0,    6,    6,    0,
        6,    0,    0,    0,    0,    0,    0,    0,    0,    0,
        0,    3,    0,    0,    6,    0,    0,    0,    0,    0,
        0,    6,    6,    0,    2,    4,    1,    1,    0,    6,
        0,    0,    0,    1,    0,    0,    1,    2,    4,    0
    } ;

static yyconst flex_int32_t yy_ec[256] =
    {   0,
        1,    1,    1,    1,    1,    1,    1,    1,    2,    3,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    2,    1,    1,    1,    1,    1,    1,    1,    4,
        4,    1,    5,    6,    7,    1,    8,    9,   10,    9,
        9,    9,    9,    9,    9,    9,    9,   11,    1,    1,
        1,    1,    1,    1,   12,    1,   13,   14,   15,   16,
       17,   18,    1,   19,    1,    1,   20,   21,   22,   23,
        1,    1,   24,   25,   26,    1,   27,    1,    1,    1,
       28,    1,   29,    1,    1,    1,   30,   31,   32,   33,

       34,   16,   35,   36,   37,   19,    1,   38,   39,   40,
       41,   42,    1,   43,   44,   45,   46,   47,   27,    1,
       48,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,

        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1
    } ;

static yyconst flex_int32_t yy_meta[49] =
    {   0,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1
    } ;

static yyconst flex_int16_t yy_base[571] =
    {   0,
        0,    0,  907,  908,   37,   52,   55,   78,   24,  872,
       25,   44,   48,  864,  872,   61,   46,  869,   81,   70,
       82,   84,  882,   85,   86,  877,   87,  875,   69,   70,
       72,  860,   79,   82,  854,   84,  852,  109,  111,  127,
      115,  125,  853,  860,  862,  862,  855,  851,   13,   87,
      850,  842,  843,  842,  844,  845,  838,  849,  849,  851,
      838,  854,  853,  852,  851,  850,  849,  848,  847,  846,
      845,  844,  843,  842,  841,  908,  820,  819,  818,  817,
      816,  815,  814,  813,  812,  811,  810,  809,  808,  807,
      127,  135,   92,  817,  816,   51,  819,  807,  815,  812,

      145,  138,  140,  129,  148,  156,  154,  157,  159,  162,
      843,  163,  168,  170,  171,  174,  176,  177,  178,  186,
      815,  814,  908,  908,  908,  908,  908,  908,  908,  908,
      908,  908,  908,  908,  908,  908,  188,  194,  799,  806,
      808,  808,  798,  147,  147,  790,  791,  793,  197,  205,
      206,  796,  789,  793,  785,  225,  828,  799,  798,  825,
      824,  789,  794,  784,  791,  778,  786,  789,  774,  784,
      782,  787,  786,  908,  908,  199,  172,  197,  208,  179,
      212,  219,  222,  811,  227,  221,  226,  223,  233,  266,
      810,  766,  779,  779,  268,  206,  774,  773,  210,  776,

      764,  772,  769,  754,  758,  798,  751,  767,  763,  763,
      756,  746,  760,  762,  747,  770,  769,  271,  750,  743,
      747,  739,  754,  781,  780,  745,  741,  748,  744,  277,
      280,  282,  775,  257,  774,  741,  731,  291,  771,  729,
      736,  738,  738,  728,  245,  251,  720,  721,  723,  294,
      716,  295,  729,  719,  731,  729,  296,  729,  710,  724,
      717,  716,  299,  307,  752,  708,  721,  721,  707,  747,
      717,  713,  707,  316,  310,  327,  313,  318,  702,  696,
      292,  709,  708,  258,  711,  699,  707,  704,  304,  228,
      312,  331,  293,  338,  341,  340,  735,  342,  343,  345,

      693,  733,  686,  699,  684,  346,  701,  701,  700,  347,
      349,  726,  693,  683,  677,  690,  680,  691,  344,  719,
      358,  360,  718,  717,  675,  682,  684,  684,  674,  323,
      330,  666,  667,  669,  378,  672,  665,  669,  661,  676,
      703,  702,  667,  663,  670,  666,  697,  375,  655,  377,
      649,  908,  908,  383,  385,  387,  653,  647,  651,  691,
      658,  680,  389,  398,  688,  392,  401,  369,  363,  348,
      389,  402,  403,  406,  413,  687,  410,  411,  414,  418,
      686,  642,  655,  655,  641,  681,  651,  647,  641,  677,
      415,  420,  676,  675,  674,  673,  631,  424,  630,  631,

      389,  221,  637,  444,  445,  632,  625,  629,  621,  636,
      663,  662,  627,  623,  630,  626,  447,  657,  456,  656,
      623,  613,  607,  620,  610,  621,  640,  429,  648,  638,
      611,  607,  601,  605,  598,  609,  609,  451,  454,  639,
      595,  608,  608,  594,  634,  604,  600,  594,  456,  459,
      469,  589,  583,  587,  627,  594,  463,  465,  594,  593,
      579,  591,  580,  578,  581,  474,  478,  618,  585,  575,
      569,  582,  572,  583,  480,  483,  492,  486,  490,  611,
      610,  609,  567,  598,  495,  578,  577,  563,  575,  560,
      570,  568,  504,  498,  507,  558,  552,  556,  596,  563,

      509,  594,  511,  513,  522,  524,  533,  593,  527,  908,
      546,  545,  559,  543,  557,  559,  544,  535,  585,  584,
      583,  525,  482,  538,  475,  527,  531,  908,  908,  485,
      908,  482,  462,  464,  474,  541,  451,  430,  543,  552,
      546,  908,  388,  378,  908,  220,  548,  550,  554,  556,
      558,  908,  908,  190,  111,   64,  560,  562,   54,  908,
      564,  566,  568,  570,  572,  574,  908,  908,  908,  908
    } ;

static yyconst flex_int16_t yy_def[571] =
    {   0,
      570,    1,  570,  570,  570,  570,  570,  570,  570,  570,
      570,  570,  570,  570,  570,  570,  570,  570,  570,  570,
      570,  570,  570,  570,  570,  570,  570,  570,  570,  570,
      570,  570,  570,  570,  570,  570,  570,  570,  570,  570,
      570,  570,  570,  570,  570,  570,  570,  570,  570,  570,
      570,  570,  570,  570,  570,  570,  570,  570,  570,  570,
      570,  570,  570,  570,  570,  570,  570,  570,  570,  570,
      570,  570,  570,  570,  570,  570,  570,  570,  570,  570,
      570,  570,  570,  570,  570,  570,  570,  570,  570,  570,
      570,  570,  570,  570,  570,  570,  570,  570,  570,  570,

      570,  570,  570,  570,  570,  570,  570,  570,  570,  570,
      570,  570,  570,  570,  570,  570,  570,  570,  570,  570,
      570,  570,  570,  570,  570,  570,  570,  570,  570,  570,
      570,  570,  570,  570,  570,  570,  570,  570,  570,  570,
      570,  570,  570,  570,  570,  570,  570,  570,  570,  570,
      570,  570,  570,  570,  570,  570,  570,  570,  570,  570,
      570,  570,  570,  570,  570,  570,  570,  570,  570,  570,
      570,  570,  570,  570,  570,  570,  570,  570,  570,  570,
      570,  570,  570,  570,  570,  570,  570,  570,  570,  570,
      570,  570,  570,  570,  570,  570,  570,  570,  570,  570,

      570,  570,  570,  570,  570,  570,  570,  570,  570,  570,
      570,  570,  570,  570,  570,  570,  570,  570,  570,  570,
      570,  570,  570,  570,  570,  570,  570,  570,  570,  570,
      570,  570,  570,  570,  570,  570,  570,  570,  570,  570,
      570,  570,  570,  570,  570,  570,  570,  570,  570,  570,
      570,  570,  570,  570,  570,  570,  570,  570,  570,  570,
      570,  570,  570,  570,  570,  570,  570,  570,  570,  570,
      570,  570,  570,  570,  570,  570,  570,  570,  570,  570,
      570,  570,  570,  570,  570,  570,  570,  570,  570,  570,
      570,  570,  570,  570,  570,  570,  570,  570,  570,  570,

      570,  570,  570,  570,  570,  570,  570,  570,  570,  570,
      570,  570,  570,  570,  570,  570,  570,  570,  570,  570,
      570,  570,  570,  570,  570,  570,  570,  570,  570,  570,
      570,  570,  570,  570,  570,  570,  570,  570,  570,  570,
      570,  570,  570,  570,  570,  570,  570,  570,  570,  570,
      570,  570,  570,  570,  570,  570,  570,  570,  570,  570,
      570,  570,  570,  570,  570,  570,  570,  570,  570,  570,
      570,  570,  570,  570,  570,  570,  570,  570,  570,  570,
      570,  570,  570,  570,  570,  570,  570,  570,  570,  570,
      570,  570,  570,  570,  570,  570,  570,  570,  570,  570,

      570,  570,  570,  570,  570,  570,  570,  570,  570,  570,
      570,  570,  570,  570,  570,  570,  570,  570,  570,  570,
      570,  570,  570,  570,  570,  570,  570,  570,  570,  570,
      570,  570,  570,  570,  570,  570,  570,  570,  570,  570,
      570,  570,  570,  570,  570,  570,  570,  570,  570,  570,
      570,  570,  570,  570,  570,  570,  570,  570,  570,  570,
      570,  570,  570,  570,  570,  570,  570,  570,  570,  570,
      570,  570,  570,  570,  570,  570,  570,  570,  570,  570,
      570,  570,  570,  570,  570,  570,  570,  570,  570,  570,
      570,  570,  570,  570,  570,  570,  570,  570,  570,  570,

      570,  570,  570,  570,  570,  570,  570,  570,  570,  570,
      570,  570,  570,  570,  570,  570,  570,  570,  570,  570,
      570,  570,  570,  570,  570,  570,  570,  570,  570,  570,
      570,  570,  570,  570,  570,  570,  570,  570,  570,  570,
      570,  570,  570,  570,  570,  570,  570,  570,  570,  570,
      570,  570,  570,  570,  570,  570,  570,  570,  570,  570,
      570,  570,  570,  570,  570,  570,  570,  570,  570,    0
    } ;

static yyconst flex_int16_t yy_nxt[957] =
    {   0,
        4,    5,    5,    5,    6,    4,    7,    4,    8,    8,
        4,    9,    4,   10,    4,   11,    4,    4,   12,   13,
       14,   15,    4,   16,   17,    4,   18,   19,    4,    9,
        4,    4,   10,    4,    4,    4,    4,    4,   13,   14,
       15,    4,    4,   16,   17,    4,    4,    4,   20,   21,
      108,   22,  109,   23,   24,  540,   25,   26,   46,   27,
       38,   38,   28,   39,   39,   43,   29,   47,   30,   44,
       31,   32,   33,   48,  562,   34,   35,   50,   36,   40,
      143,   57,   37,   62,   41,   41,   42,   42,   51,   49,
       54,   58,   60,   63,   55,   64,  144,   66,   69,   71,

       74,   77,   79,   61,   81,   65,   56,   67,   70,   72,
       75,   84,   78,   80,   86,   82,   89,   91,   91,   92,
       92,  561,   85,  101,  101,   87,   40,   90,   40,  110,
      151,   41,   41,  139,  111,  137,  137,  140,   93,  151,
       94,  151,   95,  138,  138,   96,   97,   98,   99,  151,
      100,  149,  149,  150,  150,  151,   93,  156,  151,   94,
      151,  157,  154,  151,  156,   97,   98,   99,  157,  151,
      100,  151,  156,  218,  152,  151,  157,  156,  156,  156,
      218,  157,  157,  157,  181,  153,  182,  156,  158,  183,
      155,  157,  161,  162,  184,  163,  174,  174,  218,  159,

      218,  164,  175,  175,  160,  188,  189,  151,  168,  218,
      165,  149,  149,  218,  190,  190,  166,  220,  167,  169,
      218,  170,  218,  218,  223,  171,  156,  218,  218,  335,
      221,  230,  230,  195,  195,  219,  196,  560,  197,  244,
      198,  231,  231,  199,  200,  201,  202,  240,  203,  554,
      222,  241,  225,  226,  196,  245,  435,  197,  232,  224,
      227,  228,  233,  200,  201,  202,  436,  232,  203,  238,
      229,  233,  218,  337,  234,  234,  239,  239,  274,  263,
      264,  274,  294,  232,  295,  275,  275,  329,  276,  276,
      277,  278,  238,  296,  335,  156,  156,  156,  297,  157,

      157,  157,  281,  330,  282,  335,  283,  310,  310,  284,
      285,  286,  287,  335,  288,  311,  311,  274,  320,  320,
      281,  321,  321,  282,  319,  319,  322,  322,  274,  285,
      286,  287,  335,  325,  288,  320,  320,  326,  340,  335,
      336,  335,  335,  335,  335,  338,  335,  156,  354,  405,
      354,  157,  362,  362,  363,  355,  355,  356,  356,  364,
      373,  364,  374,  365,  405,  365,  366,  366,  367,  367,
      405,  343,  375,  339,  342,  344,  156,  376,  156,  335,
      157,  408,  157,  345,  354,  341,  380,  380,  354,  346,
      405,  392,  392,  393,  393,  393,  393,  398,  398,  364,

      404,  404,  364,  405,  405,  406,  365,  405,  407,  404,
      404,  405,  405,  399,  405,  405,  156,  400,  433,  417,
      157,  401,  402,  418,  403,  553,  419,  419,  427,  427,
      428,  409,  430,  430,  434,  552,  400,  457,  457,  412,
      539,  401,  402,  414,  413,  364,  405,  410,  417,  365,
      411,  415,  405,  438,  439,  449,  450,  417,  416,  466,
      466,  418,  467,  467,  475,  475,  476,  477,  477,  476,
      451,  484,  484,  485,  485,  493,  501,  478,  479,  493,
      502,  501,  494,  494,  536,  502,  495,  495,  503,  503,
      476,  504,  504,  501,  506,  506,  546,  502,  507,  507,

      505,  505,  476,  510,  510,  493,  519,  519,  493,  545,
      501,  544,  518,  518,  543,  519,  519,  524,  524,  525,
      525,  526,  526,  501,  537,  501,  405,  502,  540,  502,
      525,  525,  503,  503,  501,  527,  527,  541,  502,  542,
      542,  505,  505,  535,  535,  536,  538,  538,  539,  547,
      547,  548,  548,  540,  551,  551,  555,  555,  556,  556,
      549,  550,  557,  557,  558,  558,  559,  559,  563,  563,
      564,  564,  565,  565,  566,  566,  567,  567,  567,  567,
      568,  568,  569,  569,  405,  405,  493,  534,  533,  532,
      531,  530,  529,  528,  335,  501,  523,  405,  522,  521,

      520,  517,  516,  515,  514,  513,  512,  511,  509,  508,
      335,  335,  335,  500,  499,  498,  376,  497,  496,  405,
      492,  491,  490,  489,  488,  487,  486,  483,  335,  482,
      481,  480,  474,  473,  472,  405,  471,  470,  469,  468,
      405,  465,  464,  463,  462,  461,  460,  459,  458,  218,
      428,  456,  455,  454,  297,  453,  452,  335,  451,  448,
      447,  446,  445,  405,  405,  444,  443,  442,  441,  440,
      437,  432,  431,  429,  218,  218,  218,  354,  151,  426,
      425,  424,  335,  423,  422,  421,  420,  335,  405,  364,
      363,  397,  218,  396,  395,  394,  391,  390,  151,  389,

      388,  387,  386,  335,  335,  385,  384,  383,  382,  381,
      379,  378,  377,  372,  371,  370,  369,  368,  151,  151,
      274,  361,  360,  359,  184,  358,  357,  218,  353,  352,
      351,  350,  349,  348,  151,  347,  335,  334,  333,  332,
      331,  328,  327,  324,  323,  318,  317,  316,  218,  315,
      314,  313,  312,  218,  309,  308,  307,  306,  305,  304,
      303,  302,  301,  111,  300,  299,  298,  293,  292,  291,
      290,  289,  238,  280,  279,  151,  232,  273,  272,  271,
      270,  218,  218,  269,  268,  267,  266,  265,  262,  261,
      260,  259,  258,  257,  256,  255,  254,  253,  252,  151,

      251,  250,  249,  248,  247,  246,  243,  242,  237,  236,
      235,  151,  218,  217,  216,  215,  214,  213,  212,  211,
      210,  209,  208,  207,  206,  151,  151,  205,  204,  156,
      194,  193,  192,  191,  187,  186,  185,  180,  179,  178,
      177,  176,  173,  172,  151,  148,  147,  146,  145,  142,
      141,  136,  135,  134,  133,  132,  131,  130,  129,  128,
      127,  126,  125,  124,  123,  136,  135,  134,  133,  132,
      131,  130,  129,  128,  127,  126,  125,  124,  123,  122,
      121,  120,  119,  118,  117,  116,  115,  114,  113,  112,
      107,  106,  105,  104,  103,  102,   76,   88,   83,   76,

       73,   68,   59,   53,   52,   45,  570,    3,  570,  570,
      570,  570,  570,  570,  570,  570,  570,  570,  570,  570,
      570,  570,  570,  570,  570,  570,  570,  570,  570,  570,
      570,  570,  570,  570,  570,  570,  570,  570,  570,  570,
      570,  570,  570,  570,  570,  570,  570,  570,  570,  570,
      570,  570,  570,  570,  570,  570
    } ;

static yyconst flex_int16_t yy_chk[957] =
    {   0,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    5,    5,
       49,    5,   49,    5,    5,  559,    5,    5,   11,    5,
        6,    6,    5,    7,    7,    9,    5,   11,    5,    9,
        5,    5,    5,   12,  556,    5,    5,   13,    5,    8,
       96,   17,    5,   20,    8,    8,    8,    8,   13,   12,
       16,   17,   19,   20,   16,   21,   96,   22,   24,   25,

       27,   29,   30,   19,   31,   21,   16,   22,   24,   25,
       27,   33,   29,   30,   34,   31,   36,   38,   38,   39,
       39,  555,   33,   41,   41,   34,   42,   36,   40,   50,
      104,   42,   42,   93,   50,   91,   91,   93,   40,  102,
       40,  103,   40,   92,   92,   40,   40,   40,   40,  105,
       40,  101,  101,  101,  101,  107,   40,  106,  108,   40,
      109,  106,  104,  110,  112,   40,   40,   40,  112,  113,
       40,  114,  115,  177,  102,  116,  115,  117,  118,  119,
      180,  117,  118,  119,  144,  103,  144,  120,  106,  145,
      105,  120,  109,  110,  145,  112,  137,  137,  178,  107,

      176,  113,  138,  138,  108,  149,  149,  151,  117,  179,
      114,  150,  150,  181,  151,  151,  115,  177,  116,  118,
      182,  119,  186,  183,  180,  120,  156,  187,  185,  290,
      178,  188,  188,  156,  156,  176,  156,  554,  156,  199,
      156,  189,  189,  156,  156,  156,  156,  196,  156,  546,
      179,  196,  182,  183,  156,  199,  402,  156,  234,  181,
      185,  186,  234,  156,  156,  156,  402,  190,  156,  195,
      187,  190,  218,  290,  190,  190,  195,  195,  230,  218,
      218,  231,  245,  232,  245,  230,  230,  284,  231,  231,
      232,  232,  238,  246,  293,  250,  252,  257,  246,  250,

      252,  257,  238,  284,  238,  289,  238,  263,  263,  238,
      238,  238,  238,  291,  238,  264,  264,  274,  275,  275,
      238,  277,  277,  238,  274,  274,  278,  278,  276,  238,
      238,  238,  292,  281,  238,  276,  276,  281,  293,  294,
      289,  296,  295,  298,  299,  291,  300,  306,  310,  370,
      311,  306,  319,  319,  319,  310,  310,  311,  311,  321,
      330,  322,  330,  321,  369,  322,  321,  321,  322,  322,
      368,  296,  331,  292,  295,  298,  348,  331,  350,  335,
      348,  370,  350,  299,  354,  294,  335,  335,  356,  300,
      371,  354,  354,  355,  355,  356,  356,  363,  363,  364,

      366,  366,  367,  372,  373,  368,  367,  374,  369,  367,
      367,  377,  378,  364,  375,  379,  391,  364,  401,  380,
      391,  364,  364,  380,  364,  544,  380,  380,  392,  392,
      392,  371,  398,  398,  401,  543,  364,  428,  428,  374,
      538,  364,  364,  377,  375,  404,  405,  372,  417,  404,
      373,  378,  537,  405,  405,  417,  417,  419,  379,  438,
      438,  419,  439,  439,  449,  449,  449,  450,  450,  450,
      451,  457,  457,  458,  458,  466,  525,  451,  451,  467,
      525,  475,  466,  466,  535,  475,  467,  467,  475,  475,
      475,  476,  476,  477,  478,  478,  534,  477,  479,  479,

      477,  477,  477,  485,  485,  493,  494,  494,  495,  533,
      501,  532,  493,  493,  530,  495,  495,  501,  501,  503,
      503,  504,  504,  505,  523,  506,  522,  505,  526,  506,
      505,  505,  506,  506,  507,  509,  509,  526,  507,  527,
      527,  507,  507,  518,  518,  518,  524,  524,  524,  536,
      536,  539,  539,  540,  541,  541,  547,  547,  548,  548,
      540,  540,  549,  549,  550,  550,  551,  551,  557,  557,
      558,  558,  561,  561,  562,  562,  563,  563,  564,  564,
      565,  565,  566,  566,  521,  520,  519,  517,  516,  515,
      514,  513,  512,  511,  508,  502,  500,  499,  498,  497,

      496,  492,  491,  490,  489,  488,  487,  486,  484,  483,
      482,  481,  480,  474,  473,  472,  471,  470,  469,  468,
      465,  464,  463,  462,  461,  460,  459,  456,  455,  454,
      453,  452,  448,  447,  446,  445,  444,  443,  442,  441,
      440,  437,  436,  435,  434,  433,  432,  431,  430,  429,
      427,  426,  425,  424,  423,  422,  421,  420,  418,  416,
      415,  414,  413,  412,  411,  410,  409,  408,  407,  406,
      403,  400,  399,  397,  396,  395,  394,  393,  390,  389,
      388,  387,  386,  385,  384,  383,  382,  381,  376,  365,
      362,  361,  360,  359,  358,  357,  351,  349,  347,  346,

      345,  344,  343,  342,  341,  340,  339,  338,  337,  336,
      334,  333,  332,  329,  328,  327,  326,  325,  324,  323,
      320,  318,  317,  316,  315,  314,  313,  312,  309,  308,
      307,  305,  304,  303,  302,  301,  297,  288,  287,  286,
      285,  283,  282,  280,  279,  273,  272,  271,  270,  269,
      268,  267,  266,  265,  262,  261,  260,  259,  258,  256,
      255,  254,  253,  251,  249,  248,  247,  244,  243,  242,
      241,  240,  239,  237,  236,  235,  233,  229,  228,  227,
      226,  225,  224,  223,  222,  221,  220,  219,  217,  216,
      215,  214,  213,  212,  211,  210,  209,  208,  207,  206,

      205,  204,  203,  202,  201,  200,  198,  197,  194,  193,
      192,  191,  184,  173,  172,  171,  170,  169,  168,  167,
      166,  165,  164,  163,  162,  161,  160,  159,  158,  157,
      155,  154,  153,  152,  148,  147,  146,  143,  142,  141,
      140,  139,  122,  121,  111,  100,   99,   98,   97,   95,
       94,   90,   89,   88,   87,   86,   85,   84,   83,   82,
       81,   80,   79,   78,   77,   75,   74,   73,   72,   71,
       70,   69,   68,   67,   66,   65,   64,   63,   62,   61,
       60,   59,   58,   57,   56,   55,   54,   53,   52,   51,
       48,   47,   46,   45,   44,   43,   37,   35,   32,   28,

       26,   23,   18,   15,   14,   10,    3,  570,  570,  570,
      570,  570,  570,  570,  570,  570,  570,  570,  570,  570,
      570,  570,  570,  570,  570,  570,  570,  570,  570,  570,
      570,  570,  570,  570,  570,  570,  570,  570,  570,  570,
      570,  570,  570,  570,  570,  570,  570,  570,  570,  570,
      570,  570,  570,  570,  570,  570
    } ;

static yy_state_type yy_last_accepting_state;
static char *yy_last_accepting_cpos;

extern int yy_flex_debug;
int yy_flex_debug = 0;

/* The intent behind this definition is that it'll catch
 * any uses of REJECT which flex missed.
 */
#define REJECT reject_used_but_not_detected
#define yymore() yymore_used_but_not_detected
#define YY_MORE_ADJ 0
#define YY_RESTORE_YY_MORE_OFFSET
char *yytext;
#line 1 "/Users/kenh/nmh/sbr/dtimep.l"
/* dtimep.lex exceeds the default table capacities for some old versions
 * of lex (and the minimum defaults as specified by POSIX).  The following
 * choices meet or exceed the lex defaults for older SunOS4.x, Solaris,
 * HPUX, and AIX.
 */
#line 11 "/Users/kenh/nmh/sbr/dtimep.l"
#include <h/nmh.h>
#include <h/tws.h>

  /* Since we're looking at a string at a time, don't worry about
   *  wrapping to the next buffer.
   */
#define yywrap() 1
#define YY_SKIP_YYWRAP

#define YY_NO_INPUT

  /* This is the tricky thing that makes this function cool.  We
   *  replace the traditional int yylex(void) declaration with our
   *  dparsetime() declaration, essentially piggy-backing off the
   *  utility of the yylex() function and adding what we need to make
   *  the parsing function useful to us.
   */
#define YY_DECL struct tws *dparsetime(char *lexstr)

  /* yyerminate() is called after the input string is matched to
   * completion (actually, when the lexer reaches an EOF).  The only
   * thing that really needs to be in this macro function is the
   * return call, which must be substituted inline into dparsetime.
   */

#define yyterminate() (void)yy_delete_buffer(lexhandle); \
  if(!(tw.tw_flags & TW_SUCC)) { \
    return (struct tws *)NULL; \
  } \
  if(tw.tw_year < 1970) \
    tw.tw_year += 1900; \
  if(tw.tw_year < 1970) \
    tw.tw_year += 100; \
  return(&tw)

/*
 * Patchable flag that says how to interpret NN/NN/NN dates. When
 * true, we do it European style: DD/MM/YY. When false, we do it
 * American style: MM/DD/YY.  Of course, these are all non-RFC822
 * compliant.
 */
int europeandate = 0;

/*
 * Table to convert month names to numeric month.  We use the
 * fact that the low order 5 bits of the sum of the 2nd & 3rd
 * characters of the name is a hash with no collisions for the 12
 * valid month names.  (The mask to 5 bits maps any combination of
 * upper and lower case into the same hash value).
 */
static int month_map[] = {
	0,
	6,	/* 1 - Jul */
	3,	/* 2 - Apr */
	5,	/* 3 - Jun */
	0,
	10,	/* 5 - Nov */
	0,
	1,	/* 7 - Feb */
	11,	/* 8 - Dec */
	0,
	0,
	0,
	0,
	0,
	0,
	0,	/*15 - Jan */
	0,
	0,
	0,
	2,	/*19 - Mar */
	0,
	8,	/*21 - Sep */
	0,
	9,	/*23 - Oct */
	0,
	0,
	4,	/*26 - May */
	0,
	7	/*28 - Aug */
};

/*
 * Lookup table for day-of-week using the same hash trick as for above name-of-
 * month table, but using the first and second character, not second and third.
 *
 * Compute index into table using: (day_name[0] & 7) + (day_name[1] & 4)
 */
static int day_map[] = {
	0,
	0,
	0,
	6,	/* 3 - Sat */
	4,	/* 4 - Thu */
	0,
	5,	/* 6 - Fri */
	0,	/* 7 - Sun */
	2,	/* 8 - Tue */
	1	/* 9 - Mon */,
	0,
	3	/*11 - Wed */
};

/* The SET* macros will parse for the appropriate field, and leave the
 * cp pointer at the first character after the desired field. Be
 * careful with variable-length fields or alpha-num mixes.

 * The SKIP* macros skip over characters of a particular class and
 * leave cp at the position of the first character that doesn't match
 * that class. Correspondingly, SKIPTO* skips until it reaches a
 * character of a particular class.
 */

#define INIT()       { cp = yytext;} 
#define SETWDAY()    { tw.tw_wday= day_map[(cp[0] & 7) + (cp[1] & 4)]; \
                       tw.tw_flags &= ~TW_SDAY; tw.tw_flags |= TW_SEXP; \
                       SKIPA(); }
#define SETMON()     { cp++; \
                       tw.tw_mon = month_map[(((unsigned char) cp[0]) + ((unsigned char) cp[1])) & 0x1f]; \
  		       SKIPA(); }
#define SETMON_NUM() { tw.tw_mon = atoi(cp)-1; \
  		       SKIPD(); }
#define SETYEAR()    { tw.tw_year = atoi(cp); \
  		       SKIPD(); }
#define SETDAY()     { tw.tw_mday = atoi(cp); \
                       tw.tw_flags |= TW_YES; \
  		       SKIPD(); }
#define SETTIME()    { tw.tw_hour = atoi(cp); \
                       cp += 2; \
                       SKIPTOD(); \
                       tw.tw_min = atoi(cp); \
                       cp += 2; \
                       if(*cp == ':') { \
                          tw.tw_sec = atoi(++cp); SKIPD(); } }
#define SETZONE(x)   { tw.tw_zone = ((x)/100)*60+(x)%100; \
                       tw.tw_flags |= TW_SZEXP; \
                       SKIPD(); }
#define SETDST()     { tw.tw_flags |= TW_DST; }
#define SKIPD()      { while ( isdigit((unsigned char) *cp++) ) ; \
                       --cp; }
#define SKIPTOD()    { while ( !isdigit((unsigned char) *cp++) ) ; \
                       --cp; }
#define SKIPA()      { while ( isalpha((unsigned char) *cp++) ) ; \
                       --cp; }
#define SKIPTOA()    { while ( !isalpha((unsigned char) *cp++) ) ; \
                       --cp; }
#define SKIPSP()     { while ( isspace((unsigned char) *cp++) ) ; \
                       --cp; }
#define SKIPTOSP()   { while ( !isspace((unsigned char) *cp++) ) ; \
                       --cp; }

#ifdef ADJUST_NUMERIC_ONLY_TZ_OFFSETS_WRT_DST
# ifdef HAVE_SYS_TIME_H
#  include <sys/time.h>
# endif
#include <time.h>

static void
zonehack (struct tws *tw)
{
    register struct tm *tm;

    if (dmktime (tw) == (time_t) -1)
	return;

    tm = localtime (&tw->tw_clock);
    if (tm->tm_isdst) {
	tw->tw_flags |= TW_DST;
	tw->tw_zone -= 60;
    }
}
#endif	/* ADJUST_NUMERIC_ONLY_TZ_OFFSETS_WRT_DST */
/* The year can either be 2 digits, or 4. However, after
Y2K, we found that some MUA were reporting the year 100, hence
the middle term here. yyterminate() resolves the actual
issues with 2-digit years.
*/
#line 1028 "sbr/dtimep.c"

#define INITIAL 0

#ifndef YY_NO_UNISTD_H
/* Special case for "unistd.h", since it is non-ANSI. We include it way
 * down here because we want the user's section 1 to have been scanned first.
 * The user has a chance to override it with an option.
 */
#include <unistd.h>
#endif

#ifndef YY_EXTRA_TYPE
#define YY_EXTRA_TYPE void *
#endif

static int yy_init_globals (void );

/* Accessor methods to globals.
   These are made visible to non-reentrant scanners for convenience. */

int yylex_destroy (void );

int yyget_debug (void );

void yyset_debug (int debug_flag  );

YY_EXTRA_TYPE yyget_extra (void );

void yyset_extra (YY_EXTRA_TYPE user_defined  );

FILE *yyget_in (void );

void yyset_in  (FILE * in_str  );

FILE *yyget_out (void );

void yyset_out  (FILE * out_str  );

yy_size_t yyget_leng (void );

char *yyget_text (void );

int yyget_lineno (void );

void yyset_lineno (int line_number  );

/* Macros after this point can all be overridden by user definitions in
 * section 1.
 */

#ifndef YY_SKIP_YYWRAP
#ifdef __cplusplus
extern "C" int yywrap (void );
#else
extern int yywrap (void );
#endif
#endif

    static void yyunput (int c,char *buf_ptr  );
    
#ifndef yytext_ptr
static void yy_flex_strncpy (char *,yyconst char *,int );
#endif

#ifdef YY_NEED_STRLEN
static int yy_flex_strlen (yyconst char * );
#endif

#ifndef YY_NO_INPUT

#ifdef __cplusplus
static int yyinput (void );
#else
static int input (void );
#endif

#endif

/* Amount of stuff to slurp up with each read. */
#ifndef YY_READ_BUF_SIZE
#define YY_READ_BUF_SIZE 8192
#endif

/* Copy whatever the last rule matched to the standard output. */
#ifndef ECHO
/* This used to be an fputs(), but since the string might contain NUL's,
 * we now use fwrite().
 */
#define ECHO fwrite( yytext, yyleng, 1, yyout )
#endif

/* Gets input and stuffs it into "buf".  number of characters read, or YY_NULL,
 * is returned in "result".
 */
#ifndef YY_INPUT
#define YY_INPUT(buf,result,max_size) \
	if ( YY_CURRENT_BUFFER_LVALUE->yy_is_interactive ) \
		{ \
		int c = '*'; \
		yy_size_t n; \
		for ( n = 0; n < max_size && \
			     (c = getc( yyin )) != EOF && c != '\n'; ++n ) \
			buf[n] = (char) c; \
		if ( c == '\n' ) \
			buf[n++] = (char) c; \
		if ( c == EOF && ferror( yyin ) ) \
			YY_FATAL_ERROR( "input in flex scanner failed" ); \
		result = n; \
		} \
	else \
		{ \
		errno=0; \
		while ( (result = fread(buf, 1, max_size, yyin))==0 && ferror(yyin)) \
			{ \
			if( errno != EINTR) \
				{ \
				YY_FATAL_ERROR( "input in flex scanner failed" ); \
				break; \
				} \
			errno=0; \
			clearerr(yyin); \
			} \
		}\
\

#endif

/* No semi-colon after return; correct usage is to write "yyterminate();" -
 * we don't want an extra ';' after the "return" because that will cause
 * some compilers to complain about unreachable statements.
 */
#ifndef yyterminate
#define yyterminate() return YY_NULL
#endif

/* Number of entries by which start-condition stack grows. */
#ifndef YY_START_STACK_INCR
#define YY_START_STACK_INCR 25
#endif

/* Report a fatal error. */
#ifndef YY_FATAL_ERROR
#define YY_FATAL_ERROR(msg) yy_fatal_error( msg )
#endif

/* end tables serialization structures and prototypes */

/* Default declaration of generated scanner - a define so the user can
 * easily add parameters.
 */
#ifndef YY_DECL
#define YY_DECL_IS_OURS 1

extern int yylex (void);

#define YY_DECL int yylex (void)
#endif /* !YY_DECL */

/* Code executed at the beginning of each rule, after yytext and yyleng
 * have been set up.
 */
#ifndef YY_USER_ACTION
#define YY_USER_ACTION
#endif

/* Code executed at the end of each rule. */
#ifndef YY_BREAK
#define YY_BREAK break;
#endif

#define YY_RULE_SETUP \
	YY_USER_ACTION

/** The main scanner function which does all the work.
 */
YY_DECL
{
	register yy_state_type yy_current_state;
	register char *yy_cp, *yy_bp;
	register int yy_act;
    
#line 226 "/Users/kenh/nmh/sbr/dtimep.l"


  /* This section begins the definition of dparsetime().
     Put here any local variable definitions and initializations */
  
  YY_BUFFER_STATE lexhandle;

  char *cp;
  static struct tws tw; 

  memset(&tw,0,sizeof(struct tws));

  lexhandle = yy_scan_string(lexstr);


#line 1226 "sbr/dtimep.c"

	if ( !(yy_init) )
		{
		(yy_init) = 1;

#ifdef YY_USER_INIT
		YY_USER_INIT;
#endif

		if ( ! (yy_start) )
			(yy_start) = 1;	/* first start state */

		if ( ! yyin )
			yyin = stdin;

		if ( ! yyout )
			yyout = stdout;

		if ( ! YY_CURRENT_BUFFER ) {
			yyensure_buffer_stack ();
			YY_CURRENT_BUFFER_LVALUE =
				yy_create_buffer(yyin,YY_BUF_SIZE );
		}

		yy_load_buffer_state( );
		}

	while ( 1 )		/* loops until end-of-file is reached */
		{
		yy_cp = (yy_c_buf_p);

		/* Support of yytext. */
		*yy_cp = (yy_hold_char);

		/* yy_bp points to the position in yy_ch_buf of the start of
		 * the current run.
		 */
		yy_bp = yy_cp;

		yy_current_state = (yy_start);
yy_match:
		do
			{
			register YY_CHAR yy_c = yy_ec[YY_SC_TO_UI(*yy_cp)];
			if ( yy_accept[yy_current_state] )
				{
				(yy_last_accepting_state) = yy_current_state;
				(yy_last_accepting_cpos) = yy_cp;
				}
			while ( yy_chk[yy_base[yy_current_state] + yy_c] != yy_current_state )
				{
				yy_current_state = (int) yy_def[yy_current_state];
				if ( yy_current_state >= 571 )
					yy_c = yy_meta[(unsigned int) yy_c];
				}
			yy_current_state = yy_nxt[yy_base[yy_current_state] + (unsigned int) yy_c];
			++yy_cp;
			}
		while ( yy_base[yy_current_state] != 908 );

yy_find_action:
		yy_act = yy_accept[yy_current_state];
		if ( yy_act == 0 )
			{ /* have to back up */
			yy_cp = (yy_last_accepting_cpos);
			yy_current_state = (yy_last_accepting_state);
			yy_act = yy_accept[yy_current_state];
			}

		YY_DO_BEFORE_ACTION;

do_action:	/* This label is used only to access EOF actions. */

		switch ( yy_act )
	{ /* beginning of action switch */
			case 0: /* must back up */
			/* undo the effects of YY_DO_BEFORE_ACTION */
			*yy_cp = (yy_hold_char);
			yy_cp = (yy_last_accepting_cpos);
			yy_current_state = (yy_last_accepting_state);
			goto yy_find_action;

case 1:
YY_RULE_SETUP
#line 241 "/Users/kenh/nmh/sbr/dtimep.l"
{
                                     INIT();
				     SETWDAY();
				     SKIPTOA();
				     SETMON();
				     SKIPTOD();
				     SETDAY();
				     SKIPTOD();
				     SETTIME();
				     SKIPTOD();
				     SETYEAR();
                                     }
	YY_BREAK
case 2:
YY_RULE_SETUP
#line 254 "/Users/kenh/nmh/sbr/dtimep.l"
{
                                     INIT();
				     SETWDAY();
				     SKIPTOD();
				     SETDAY();
				     SKIPTOA();
				     SETMON();
				     SKIPTOD();
				     SETYEAR();
				     SKIPTOD();
				     SETTIME();
                                     }
	YY_BREAK
case 3:
YY_RULE_SETUP
#line 266 "/Users/kenh/nmh/sbr/dtimep.l"
{
                                     INIT();
				     SETDAY();
				     SKIPTOA();
				     SETMON();
				     SKIPTOD();
				     SETYEAR();
				     SKIPTOD();
				     SETTIME();
                                     }
	YY_BREAK
case 4:
YY_RULE_SETUP
#line 276 "/Users/kenh/nmh/sbr/dtimep.l"
{
                                     INIT();
				     SETWDAY();
				     SKIPTOA();
				     SETMON();
				     SKIPTOD();
				     SETDAY();
				     SKIPTOD();
				     SETYEAR();
				     SKIPTOD();
				     SETTIME();
                                     }
	YY_BREAK
case 5:
YY_RULE_SETUP
#line 288 "/Users/kenh/nmh/sbr/dtimep.l"
{
                                     INIT();
				     SETWDAY();
				     SKIPTOA();
				     SETMON();
				     SKIPTOD();
				     SETDAY();
				     SKIPTOD();
				     SETYEAR();
                                     }
	YY_BREAK
case 6:
YY_RULE_SETUP
#line 298 "/Users/kenh/nmh/sbr/dtimep.l"
{
                                     INIT();
				     SETMON();
				     SKIPTOD();
				     SETDAY();
				     SKIPTOD();
				     SETYEAR();
				     SKIPTOA();
				     SETWDAY();
                                     }
	YY_BREAK
case 7:
YY_RULE_SETUP
#line 308 "/Users/kenh/nmh/sbr/dtimep.l"
{
                                     INIT();
				     SETMON();
				     SKIPTOD();
				     SETDAY();
				     SKIPTOD();
				     SETYEAR();
                                     }
	YY_BREAK
case 8:
YY_RULE_SETUP
#line 316 "/Users/kenh/nmh/sbr/dtimep.l"
{
                                     INIT();
				     if(europeandate) {
				       /* DD/MM/YY */
				     SETDAY();
				     SKIPTOD();
				     SETMON_NUM();
				     } else {
				       /* MM/DD/YY */
				     SETMON_NUM();
				     SKIPTOD();
				     SETDAY();
				     }
				     SKIPTOD();
				     SETYEAR();
				     SKIPTOD();
				     SETTIME();
                                     }
	YY_BREAK
case 9:
YY_RULE_SETUP
#line 334 "/Users/kenh/nmh/sbr/dtimep.l"
{
                                     INIT();
				     if(europeandate) {
				       /* DD/MM/YY */
				     SETDAY();
				     SKIPTOD();
				     SETMON_NUM();
				     } else {
				       /* MM/DD/YY */
				     SETMON_NUM();
				     SKIPTOD();
				     SETDAY();
				     }
				     SKIPTOD();
				     SETYEAR();
                                     }
	YY_BREAK
case 10:
YY_RULE_SETUP
#line 351 "/Users/kenh/nmh/sbr/dtimep.l"

	YY_BREAK
case 11:
YY_RULE_SETUP
#line 352 "/Users/kenh/nmh/sbr/dtimep.l"
tw.tw_hour += 12;
	YY_BREAK
case 12:
YY_RULE_SETUP
#line 354 "/Users/kenh/nmh/sbr/dtimep.l"
{
                                    INIT();
                                    SKIPTOD();
                                    SETZONE(atoi(cp));
#ifdef	ADJUST_NUMERIC_ONLY_TZ_OFFSETS_WRT_DST
				    zonehack (&tw);
#endif	/* ADJUST_NUMERIC_ONLY_TZ_OFFSETS_WRT_DST */
				    yyterminate();
                                    }
	YY_BREAK
case 13:
YY_RULE_SETUP
#line 363 "/Users/kenh/nmh/sbr/dtimep.l"
{
                                    INIT();
                                    SKIPTOD();
                                    SETZONE(-atoi(cp));
#ifdef	ADJUST_NUMERIC_ONLY_TZ_OFFSETS_WRT_DST
				    zonehack (&tw);
#endif	/* ADJUST_NUMERIC_ONLY_TZ_OFFSETS_WRT_DST */
				    yyterminate();
				    
                                    }
	YY_BREAK
case 14:
/* rule 14 can match eol */
YY_RULE_SETUP
#line 373 "/Users/kenh/nmh/sbr/dtimep.l"
INIT(); SETZONE(0); yyterminate();
	YY_BREAK
case 15:
/* rule 15 can match eol */
YY_RULE_SETUP
#line 374 "/Users/kenh/nmh/sbr/dtimep.l"
INIT(); SETZONE(0); yyterminate();
	YY_BREAK
case 16:
/* rule 16 can match eol */
YY_RULE_SETUP
#line 375 "/Users/kenh/nmh/sbr/dtimep.l"
INIT(); SETZONE(-500); yyterminate();
	YY_BREAK
case 17:
/* rule 17 can match eol */
YY_RULE_SETUP
#line 376 "/Users/kenh/nmh/sbr/dtimep.l"
{ INIT(); SETDST(); SETZONE(-500);
                                      yyterminate(); }
	YY_BREAK
case 18:
/* rule 18 can match eol */
YY_RULE_SETUP
#line 378 "/Users/kenh/nmh/sbr/dtimep.l"
INIT(); SETZONE(-600); yyterminate();
	YY_BREAK
case 19:
/* rule 19 can match eol */
YY_RULE_SETUP
#line 379 "/Users/kenh/nmh/sbr/dtimep.l"
{ INIT(); SETDST(); SETZONE(-600);
                                      yyterminate(); }
	YY_BREAK
case 20:
/* rule 20 can match eol */
YY_RULE_SETUP
#line 381 "/Users/kenh/nmh/sbr/dtimep.l"
INIT(); SETZONE(-700); yyterminate();
	YY_BREAK
case 21:
/* rule 21 can match eol */
YY_RULE_SETUP
#line 382 "/Users/kenh/nmh/sbr/dtimep.l"
{ INIT(); SETDST(); SETZONE(-700);
                                      yyterminate(); }
	YY_BREAK
case 22:
/* rule 22 can match eol */
YY_RULE_SETUP
#line 384 "/Users/kenh/nmh/sbr/dtimep.l"
INIT(); SETZONE(-800); yyterminate();
	YY_BREAK
case 23:
/* rule 23 can match eol */
YY_RULE_SETUP
#line 385 "/Users/kenh/nmh/sbr/dtimep.l"
{ INIT(); SETDST(); SETZONE(-800);
                                      yyterminate(); }
	YY_BREAK
case 24:
/* rule 24 can match eol */
YY_RULE_SETUP
#line 387 "/Users/kenh/nmh/sbr/dtimep.l"
INIT(); SETZONE(-330); yyterminate();
	YY_BREAK
case 25:
/* rule 25 can match eol */
YY_RULE_SETUP
#line 388 "/Users/kenh/nmh/sbr/dtimep.l"
INIT(); SETZONE(-400); yyterminate();
	YY_BREAK
case 26:
/* rule 26 can match eol */
YY_RULE_SETUP
#line 389 "/Users/kenh/nmh/sbr/dtimep.l"
{ INIT(); SETDST(); SETZONE(-400);
                                      yyterminate(); }
	YY_BREAK
case 27:
/* rule 27 can match eol */
YY_RULE_SETUP
#line 391 "/Users/kenh/nmh/sbr/dtimep.l"
INIT(); SETZONE(-1000); yyterminate();
	YY_BREAK
case 28:
/* rule 28 can match eol */
YY_RULE_SETUP
#line 392 "/Users/kenh/nmh/sbr/dtimep.l"
{ INIT(); SETDST(); SETZONE(-1000);
                                      yyterminate(); }
	YY_BREAK
case 29:
/* rule 29 can match eol */
YY_RULE_SETUP
#line 394 "/Users/kenh/nmh/sbr/dtimep.l"

	YY_BREAK
case 30:
YY_RULE_SETUP
#line 396 "/Users/kenh/nmh/sbr/dtimep.l"
ECHO;
	YY_BREAK
#line 1597 "sbr/dtimep.c"
case YY_STATE_EOF(INITIAL):
	yyterminate();

	case YY_END_OF_BUFFER:
		{
		/* Amount of text matched not including the EOB char. */
		int yy_amount_of_matched_text = (int) (yy_cp - (yytext_ptr)) - 1;

		/* Undo the effects of YY_DO_BEFORE_ACTION. */
		*yy_cp = (yy_hold_char);
		YY_RESTORE_YY_MORE_OFFSET

		if ( YY_CURRENT_BUFFER_LVALUE->yy_buffer_status == YY_BUFFER_NEW )
			{
			/* We're scanning a new file or input source.  It's
			 * possible that this happened because the user
			 * just pointed yyin at a new source and called
			 * yylex().  If so, then we have to assure
			 * consistency between YY_CURRENT_BUFFER and our
			 * globals.  Here is the right place to do so, because
			 * this is the first action (other than possibly a
			 * back-up) that will match for the new input source.
			 */
			(yy_n_chars) = YY_CURRENT_BUFFER_LVALUE->yy_n_chars;
			YY_CURRENT_BUFFER_LVALUE->yy_input_file = yyin;
			YY_CURRENT_BUFFER_LVALUE->yy_buffer_status = YY_BUFFER_NORMAL;
			}

		/* Note that here we test for yy_c_buf_p "<=" to the position
		 * of the first EOB in the buffer, since yy_c_buf_p will
		 * already have been incremented past the NUL character
		 * (since all states make transitions on EOB to the
		 * end-of-buffer state).  Contrast this with the test
		 * in input().
		 */
		if ( (yy_c_buf_p) <= &YY_CURRENT_BUFFER_LVALUE->yy_ch_buf[(yy_n_chars)] )
			{ /* This was really a NUL. */
			yy_state_type yy_next_state;

			(yy_c_buf_p) = (yytext_ptr) + yy_amount_of_matched_text;

			yy_current_state = yy_get_previous_state(  );

			/* Okay, we're now positioned to make the NUL
			 * transition.  We couldn't have
			 * yy_get_previous_state() go ahead and do it
			 * for us because it doesn't know how to deal
			 * with the possibility of jamming (and we don't
			 * want to build jamming into it because then it
			 * will run more slowly).
			 */

			yy_next_state = yy_try_NUL_trans( yy_current_state );

			yy_bp = (yytext_ptr) + YY_MORE_ADJ;

			if ( yy_next_state )
				{
				/* Consume the NUL. */
				yy_cp = ++(yy_c_buf_p);
				yy_current_state = yy_next_state;
				goto yy_match;
				}

			else
				{
				yy_cp = (yy_c_buf_p);
				goto yy_find_action;
				}
			}

		else switch ( yy_get_next_buffer(  ) )
			{
			case EOB_ACT_END_OF_FILE:
				{
				(yy_did_buffer_switch_on_eof) = 0;

				if ( yywrap( ) )
					{
					/* Note: because we've taken care in
					 * yy_get_next_buffer() to have set up
					 * yytext, we can now set up
					 * yy_c_buf_p so that if some total
					 * hoser (like flex itself) wants to
					 * call the scanner after we return the
					 * YY_NULL, it'll still work - another
					 * YY_NULL will get returned.
					 */
					(yy_c_buf_p) = (yytext_ptr) + YY_MORE_ADJ;

					yy_act = YY_STATE_EOF(YY_START);
					goto do_action;
					}

				else
					{
					if ( ! (yy_did_buffer_switch_on_eof) )
						YY_NEW_FILE;
					}
				break;
				}

			case EOB_ACT_CONTINUE_SCAN:
				(yy_c_buf_p) =
					(yytext_ptr) + yy_amount_of_matched_text;

				yy_current_state = yy_get_previous_state(  );

				yy_cp = (yy_c_buf_p);
				yy_bp = (yytext_ptr) + YY_MORE_ADJ;
				goto yy_match;

			case EOB_ACT_LAST_MATCH:
				(yy_c_buf_p) =
				&YY_CURRENT_BUFFER_LVALUE->yy_ch_buf[(yy_n_chars)];

				yy_current_state = yy_get_previous_state(  );

				yy_cp = (yy_c_buf_p);
				yy_bp = (yytext_ptr) + YY_MORE_ADJ;
				goto yy_find_action;
			}
		break;
		}

	default:
		YY_FATAL_ERROR(
			"fatal flex scanner internal error--no action found" );
	} /* end of action switch */
		} /* end of scanning one token */
} /* end of yylex */

/* yy_get_next_buffer - try to read in a new buffer
 *
 * Returns a code representing an action:
 *	EOB_ACT_LAST_MATCH -
 *	EOB_ACT_CONTINUE_SCAN - continue scanning from current position
 *	EOB_ACT_END_OF_FILE - end of file
 */
static int yy_get_next_buffer (void)
{
    	register char *dest = YY_CURRENT_BUFFER_LVALUE->yy_ch_buf;
	register char *source = (yytext_ptr);
	register int number_to_move, i;
	int ret_val;

	if ( (yy_c_buf_p) > &YY_CURRENT_BUFFER_LVALUE->yy_ch_buf[(yy_n_chars) + 1] )
		YY_FATAL_ERROR(
		"fatal flex scanner internal error--end of buffer missed" );

	if ( YY_CURRENT_BUFFER_LVALUE->yy_fill_buffer == 0 )
		{ /* Don't try to fill the buffer, so this is an EOF. */
		if ( (yy_c_buf_p) - (yytext_ptr) - YY_MORE_ADJ == 1 )
			{
			/* We matched a single character, the EOB, so
			 * treat this as a final EOF.
			 */
			return EOB_ACT_END_OF_FILE;
			}

		else
			{
			/* We matched some text prior to the EOB, first
			 * process it.
			 */
			return EOB_ACT_LAST_MATCH;
			}
		}

	/* Try to read more data. */

	/* First move last chars to start of buffer. */
	number_to_move = (int) ((yy_c_buf_p) - (yytext_ptr)) - 1;

	for ( i = 0; i < number_to_move; ++i )
		*(dest++) = *(source++);

	if ( YY_CURRENT_BUFFER_LVALUE->yy_buffer_status == YY_BUFFER_EOF_PENDING )
		/* don't do the read, it's not guaranteed to return an EOF,
		 * just force an EOF
		 */
		YY_CURRENT_BUFFER_LVALUE->yy_n_chars = (yy_n_chars) = 0;

	else
		{
			yy_size_t num_to_read =
			YY_CURRENT_BUFFER_LVALUE->yy_buf_size - number_to_move - 1;

		while ( num_to_read <= 0 )
			{ /* Not enough room in the buffer - grow it. */

			/* just a shorter name for the current buffer */
			YY_BUFFER_STATE b = YY_CURRENT_BUFFER;

			int yy_c_buf_p_offset =
				(int) ((yy_c_buf_p) - b->yy_ch_buf);

			if ( b->yy_is_our_buffer )
				{
				yy_size_t new_size = b->yy_buf_size * 2;

				if ( new_size <= 0 )
					b->yy_buf_size += b->yy_buf_size / 8;
				else
					b->yy_buf_size *= 2;

				b->yy_ch_buf = (char *)
					/* Include room in for 2 EOB chars. */
					yyrealloc((void *) b->yy_ch_buf,b->yy_buf_size + 2  );
				}
			else
				/* Can't grow it, we don't own it. */
				b->yy_ch_buf = 0;

			if ( ! b->yy_ch_buf )
				YY_FATAL_ERROR(
				"fatal error - scanner input buffer overflow" );

			(yy_c_buf_p) = &b->yy_ch_buf[yy_c_buf_p_offset];

			num_to_read = YY_CURRENT_BUFFER_LVALUE->yy_buf_size -
						number_to_move - 1;

			}

		if ( num_to_read > YY_READ_BUF_SIZE )
			num_to_read = YY_READ_BUF_SIZE;

		/* Read in more data. */
		YY_INPUT( (&YY_CURRENT_BUFFER_LVALUE->yy_ch_buf[number_to_move]),
			(yy_n_chars), num_to_read );

		YY_CURRENT_BUFFER_LVALUE->yy_n_chars = (yy_n_chars);
		}

	if ( (yy_n_chars) == 0 )
		{
		if ( number_to_move == YY_MORE_ADJ )
			{
			ret_val = EOB_ACT_END_OF_FILE;
			yyrestart(yyin  );
			}

		else
			{
			ret_val = EOB_ACT_LAST_MATCH;
			YY_CURRENT_BUFFER_LVALUE->yy_buffer_status =
				YY_BUFFER_EOF_PENDING;
			}
		}

	else
		ret_val = EOB_ACT_CONTINUE_SCAN;

	if ((yy_size_t) ((yy_n_chars) + number_to_move) > YY_CURRENT_BUFFER_LVALUE->yy_buf_size) {
		/* Extend the array by 50%, plus the number we really need. */
		yy_size_t new_size = (yy_n_chars) + number_to_move + ((yy_n_chars) >> 1);
		YY_CURRENT_BUFFER_LVALUE->yy_ch_buf = (char *) yyrealloc((void *) YY_CURRENT_BUFFER_LVALUE->yy_ch_buf,new_size  );
		if ( ! YY_CURRENT_BUFFER_LVALUE->yy_ch_buf )
			YY_FATAL_ERROR( "out of dynamic memory in yy_get_next_buffer()" );
	}

	(yy_n_chars) += number_to_move;
	YY_CURRENT_BUFFER_LVALUE->yy_ch_buf[(yy_n_chars)] = YY_END_OF_BUFFER_CHAR;
	YY_CURRENT_BUFFER_LVALUE->yy_ch_buf[(yy_n_chars) + 1] = YY_END_OF_BUFFER_CHAR;

	(yytext_ptr) = &YY_CURRENT_BUFFER_LVALUE->yy_ch_buf[0];

	return ret_val;
}

/* yy_get_previous_state - get the state just before the EOB char was reached */

    static yy_state_type yy_get_previous_state (void)
{
	register yy_state_type yy_current_state;
	register char *yy_cp;
    
	yy_current_state = (yy_start);

	for ( yy_cp = (yytext_ptr) + YY_MORE_ADJ; yy_cp < (yy_c_buf_p); ++yy_cp )
		{
		register YY_CHAR yy_c = (*yy_cp ? yy_ec[YY_SC_TO_UI(*yy_cp)] : 1);
		if ( yy_accept[yy_current_state] )
			{
			(yy_last_accepting_state) = yy_current_state;
			(yy_last_accepting_cpos) = yy_cp;
			}
		while ( yy_chk[yy_base[yy_current_state] + yy_c] != yy_current_state )
			{
			yy_current_state = (int) yy_def[yy_current_state];
			if ( yy_current_state >= 571 )
				yy_c = yy_meta[(unsigned int) yy_c];
			}
		yy_current_state = yy_nxt[yy_base[yy_current_state] + (unsigned int) yy_c];
		}

	return yy_current_state;
}

/* yy_try_NUL_trans - try to make a transition on the NUL character
 *
 * synopsis
 *	next_state = yy_try_NUL_trans( current_state );
 */
    static yy_state_type yy_try_NUL_trans  (yy_state_type yy_current_state )
{
	register int yy_is_jam;
    	register char *yy_cp = (yy_c_buf_p);

	register YY_CHAR yy_c = 1;
	if ( yy_accept[yy_current_state] )
		{
		(yy_last_accepting_state) = yy_current_state;
		(yy_last_accepting_cpos) = yy_cp;
		}
	while ( yy_chk[yy_base[yy_current_state] + yy_c] != yy_current_state )
		{
		yy_current_state = (int) yy_def[yy_current_state];
		if ( yy_current_state >= 571 )
			yy_c = yy_meta[(unsigned int) yy_c];
		}
	yy_current_state = yy_nxt[yy_base[yy_current_state] + (unsigned int) yy_c];
	yy_is_jam = (yy_current_state == 570);

	return yy_is_jam ? 0 : yy_current_state;
}

    static void yyunput (int c, register char * yy_bp )
{
	register char *yy_cp;
    
    yy_cp = (yy_c_buf_p);

	/* undo effects of setting up yytext */
	*yy_cp = (yy_hold_char);

	if ( yy_cp < YY_CURRENT_BUFFER_LVALUE->yy_ch_buf + 2 )
		{ /* need to shift things up to make room */
		/* +2 for EOB chars. */
		register yy_size_t number_to_move = (yy_n_chars) + 2;
		register char *dest = &YY_CURRENT_BUFFER_LVALUE->yy_ch_buf[
					YY_CURRENT_BUFFER_LVALUE->yy_buf_size + 2];
		register char *source =
				&YY_CURRENT_BUFFER_LVALUE->yy_ch_buf[number_to_move];

		while ( source > YY_CURRENT_BUFFER_LVALUE->yy_ch_buf )
			*--dest = *--source;

		yy_cp += (int) (dest - source);
		yy_bp += (int) (dest - source);
		YY_CURRENT_BUFFER_LVALUE->yy_n_chars =
			(yy_n_chars) = YY_CURRENT_BUFFER_LVALUE->yy_buf_size;

		if ( yy_cp < YY_CURRENT_BUFFER_LVALUE->yy_ch_buf + 2 )
			YY_FATAL_ERROR( "flex scanner push-back overflow" );
		}

	*--yy_cp = (char) c;

	(yytext_ptr) = yy_bp;
	(yy_hold_char) = *yy_cp;
	(yy_c_buf_p) = yy_cp;
}

#ifndef YY_NO_INPUT
#ifdef __cplusplus
    static int yyinput (void)
#else
    static int input  (void)
#endif

{
	int c;
    
	*(yy_c_buf_p) = (yy_hold_char);

	if ( *(yy_c_buf_p) == YY_END_OF_BUFFER_CHAR )
		{
		/* yy_c_buf_p now points to the character we want to return.
		 * If this occurs *before* the EOB characters, then it's a
		 * valid NUL; if not, then we've hit the end of the buffer.
		 */
		if ( (yy_c_buf_p) < &YY_CURRENT_BUFFER_LVALUE->yy_ch_buf[(yy_n_chars)] )
			/* This was really a NUL. */
			*(yy_c_buf_p) = '\0';

		else
			{ /* need more input */
			yy_size_t offset = (yy_c_buf_p) - (yytext_ptr);
			++(yy_c_buf_p);

			switch ( yy_get_next_buffer(  ) )
				{
				case EOB_ACT_LAST_MATCH:
					/* This happens because yy_g_n_b()
					 * sees that we've accumulated a
					 * token and flags that we need to
					 * try matching the token before
					 * proceeding.  But for input(),
					 * there's no matching to consider.
					 * So convert the EOB_ACT_LAST_MATCH
					 * to EOB_ACT_END_OF_FILE.
					 */

					/* Reset buffer status. */
					yyrestart(yyin );

					/*FALLTHROUGH*/

				case EOB_ACT_END_OF_FILE:
					{
					if ( yywrap( ) )
						return 0;

					if ( ! (yy_did_buffer_switch_on_eof) )
						YY_NEW_FILE;
#ifdef __cplusplus
					return yyinput();
#else
					return input();
#endif
					}

				case EOB_ACT_CONTINUE_SCAN:
					(yy_c_buf_p) = (yytext_ptr) + offset;
					break;
				}
			}
		}

	c = *(unsigned char *) (yy_c_buf_p);	/* cast for 8-bit char's */
	*(yy_c_buf_p) = '\0';	/* preserve yytext */
	(yy_hold_char) = *++(yy_c_buf_p);

	return c;
}
#endif	/* ifndef YY_NO_INPUT */

/** Immediately switch to a different input stream.
 * @param input_file A readable stream.
 * 
 * @note This function does not reset the start condition to @c INITIAL .
 */
    void yyrestart  (FILE * input_file )
{
    
	if ( ! YY_CURRENT_BUFFER ){
        yyensure_buffer_stack ();
		YY_CURRENT_BUFFER_LVALUE =
            yy_create_buffer(yyin,YY_BUF_SIZE );
	}

	yy_init_buffer(YY_CURRENT_BUFFER,input_file );
	yy_load_buffer_state( );
}

/** Switch to a different input buffer.
 * @param new_buffer The new input buffer.
 * 
 */
    void yy_switch_to_buffer  (YY_BUFFER_STATE  new_buffer )
{
    
	/* TODO. We should be able to replace this entire function body
	 * with
	 *		yypop_buffer_state();
	 *		yypush_buffer_state(new_buffer);
     */
	yyensure_buffer_stack ();
	if ( YY_CURRENT_BUFFER == new_buffer )
		return;

	if ( YY_CURRENT_BUFFER )
		{
		/* Flush out information for old buffer. */
		*(yy_c_buf_p) = (yy_hold_char);
		YY_CURRENT_BUFFER_LVALUE->yy_buf_pos = (yy_c_buf_p);
		YY_CURRENT_BUFFER_LVALUE->yy_n_chars = (yy_n_chars);
		}

	YY_CURRENT_BUFFER_LVALUE = new_buffer;
	yy_load_buffer_state( );

	/* We don't actually know whether we did this switch during
	 * EOF (yywrap()) processing, but the only time this flag
	 * is looked at is after yywrap() is called, so it's safe
	 * to go ahead and always set it.
	 */
	(yy_did_buffer_switch_on_eof) = 1;
}

static void yy_load_buffer_state  (void)
{
    	(yy_n_chars) = YY_CURRENT_BUFFER_LVALUE->yy_n_chars;
	(yytext_ptr) = (yy_c_buf_p) = YY_CURRENT_BUFFER_LVALUE->yy_buf_pos;
	yyin = YY_CURRENT_BUFFER_LVALUE->yy_input_file;
	(yy_hold_char) = *(yy_c_buf_p);
}

/** Allocate and initialize an input buffer state.
 * @param file A readable stream.
 * @param size The character buffer size in bytes. When in doubt, use @c YY_BUF_SIZE.
 * 
 * @return the allocated buffer state.
 */
    YY_BUFFER_STATE yy_create_buffer  (FILE * file, int  size )
{
	YY_BUFFER_STATE b;
    
	b = (YY_BUFFER_STATE) yyalloc(sizeof( struct yy_buffer_state )  );
	if ( ! b )
		YY_FATAL_ERROR( "out of dynamic memory in yy_create_buffer()" );

	b->yy_buf_size = size;

	/* yy_ch_buf has to be 2 characters longer than the size given because
	 * we need to put in 2 end-of-buffer characters.
	 */
	b->yy_ch_buf = (char *) yyalloc(b->yy_buf_size + 2  );
	if ( ! b->yy_ch_buf )
		YY_FATAL_ERROR( "out of dynamic memory in yy_create_buffer()" );

	b->yy_is_our_buffer = 1;

	yy_init_buffer(b,file );

	return b;
}

/** Destroy the buffer.
 * @param b a buffer created with yy_create_buffer()
 * 
 */
    void yy_delete_buffer (YY_BUFFER_STATE  b )
{
    
	if ( ! b )
		return;

	if ( b == YY_CURRENT_BUFFER ) /* Not sure if we should pop here. */
		YY_CURRENT_BUFFER_LVALUE = (YY_BUFFER_STATE) 0;

	if ( b->yy_is_our_buffer )
		yyfree((void *) b->yy_ch_buf  );

	yyfree((void *) b  );
}

#ifndef __cplusplus
extern int isatty (int );
#endif /* __cplusplus */
    
/* Initializes or reinitializes a buffer.
 * This function is sometimes called more than once on the same buffer,
 * such as during a yyrestart() or at EOF.
 */
    static void yy_init_buffer  (YY_BUFFER_STATE  b, FILE * file )

{
	int oerrno = errno;
    
	yy_flush_buffer(b );

	b->yy_input_file = file;
	b->yy_fill_buffer = 1;

    /* If b is the current buffer, then yy_init_buffer was _probably_
     * called from yyrestart() or through yy_get_next_buffer.
     * In that case, we don't want to reset the lineno or column.
     */
    if (b != YY_CURRENT_BUFFER){
        b->yy_bs_lineno = 1;
        b->yy_bs_column = 0;
    }

        b->yy_is_interactive = file ? (isatty( fileno(file) ) > 0) : 0;
    
	errno = oerrno;
}

/** Discard all buffered characters. On the next scan, YY_INPUT will be called.
 * @param b the buffer state to be flushed, usually @c YY_CURRENT_BUFFER.
 * 
 */
    void yy_flush_buffer (YY_BUFFER_STATE  b )
{
    	if ( ! b )
		return;

	b->yy_n_chars = 0;

	/* We always need two end-of-buffer characters.  The first causes
	 * a transition to the end-of-buffer state.  The second causes
	 * a jam in that state.
	 */
	b->yy_ch_buf[0] = YY_END_OF_BUFFER_CHAR;
	b->yy_ch_buf[1] = YY_END_OF_BUFFER_CHAR;

	b->yy_buf_pos = &b->yy_ch_buf[0];

	b->yy_at_bol = 1;
	b->yy_buffer_status = YY_BUFFER_NEW;

	if ( b == YY_CURRENT_BUFFER )
		yy_load_buffer_state( );
}

/** Pushes the new state onto the stack. The new state becomes
 *  the current state. This function will allocate the stack
 *  if necessary.
 *  @param new_buffer The new state.
 *  
 */
void yypush_buffer_state (YY_BUFFER_STATE new_buffer )
{
    	if (new_buffer == NULL)
		return;

	yyensure_buffer_stack();

	/* This block is copied from yy_switch_to_buffer. */
	if ( YY_CURRENT_BUFFER )
		{
		/* Flush out information for old buffer. */
		*(yy_c_buf_p) = (yy_hold_char);
		YY_CURRENT_BUFFER_LVALUE->yy_buf_pos = (yy_c_buf_p);
		YY_CURRENT_BUFFER_LVALUE->yy_n_chars = (yy_n_chars);
		}

	/* Only push if top exists. Otherwise, replace top. */
	if (YY_CURRENT_BUFFER)
		(yy_buffer_stack_top)++;
	YY_CURRENT_BUFFER_LVALUE = new_buffer;

	/* copied from yy_switch_to_buffer. */
	yy_load_buffer_state( );
	(yy_did_buffer_switch_on_eof) = 1;
}

/** Removes and deletes the top of the stack, if present.
 *  The next element becomes the new top.
 *  
 */
void yypop_buffer_state (void)
{
    	if (!YY_CURRENT_BUFFER)
		return;

	yy_delete_buffer(YY_CURRENT_BUFFER );
	YY_CURRENT_BUFFER_LVALUE = NULL;
	if ((yy_buffer_stack_top) > 0)
		--(yy_buffer_stack_top);

	if (YY_CURRENT_BUFFER) {
		yy_load_buffer_state( );
		(yy_did_buffer_switch_on_eof) = 1;
	}
}

/* Allocates the stack if it does not exist.
 *  Guarantees space for at least one push.
 */
static void yyensure_buffer_stack (void)
{
	yy_size_t num_to_alloc;
    
	if (!(yy_buffer_stack)) {

		/* First allocation is just for 2 elements, since we don't know if this
		 * scanner will even need a stack. We use 2 instead of 1 to avoid an
		 * immediate realloc on the next call.
         */
		num_to_alloc = 1;
		(yy_buffer_stack) = (struct yy_buffer_state**)yyalloc
								(num_to_alloc * sizeof(struct yy_buffer_state*)
								);
		if ( ! (yy_buffer_stack) )
			YY_FATAL_ERROR( "out of dynamic memory in yyensure_buffer_stack()" );
								  
		memset((yy_buffer_stack), 0, num_to_alloc * sizeof(struct yy_buffer_state*));
				
		(yy_buffer_stack_max) = num_to_alloc;
		(yy_buffer_stack_top) = 0;
		return;
	}

	if ((yy_buffer_stack_top) >= ((yy_buffer_stack_max)) - 1){

		/* Increase the buffer to prepare for a possible push. */
		int grow_size = 8 /* arbitrary grow size */;

		num_to_alloc = (yy_buffer_stack_max) + grow_size;
		(yy_buffer_stack) = (struct yy_buffer_state**)yyrealloc
								((yy_buffer_stack),
								num_to_alloc * sizeof(struct yy_buffer_state*)
								);
		if ( ! (yy_buffer_stack) )
			YY_FATAL_ERROR( "out of dynamic memory in yyensure_buffer_stack()" );

		/* zero only the new slots.*/
		memset((yy_buffer_stack) + (yy_buffer_stack_max), 0, grow_size * sizeof(struct yy_buffer_state*));
		(yy_buffer_stack_max) = num_to_alloc;
	}
}

/** Setup the input buffer state to scan directly from a user-specified character buffer.
 * @param base the character buffer
 * @param size the size in bytes of the character buffer
 * 
 * @return the newly allocated buffer state object. 
 */
YY_BUFFER_STATE yy_scan_buffer  (char * base, yy_size_t  size )
{
	YY_BUFFER_STATE b;
    
	if ( size < 2 ||
	     base[size-2] != YY_END_OF_BUFFER_CHAR ||
	     base[size-1] != YY_END_OF_BUFFER_CHAR )
		/* They forgot to leave room for the EOB's. */
		return 0;

	b = (YY_BUFFER_STATE) yyalloc(sizeof( struct yy_buffer_state )  );
	if ( ! b )
		YY_FATAL_ERROR( "out of dynamic memory in yy_scan_buffer()" );

	b->yy_buf_size = size - 2;	/* "- 2" to take care of EOB's */
	b->yy_buf_pos = b->yy_ch_buf = base;
	b->yy_is_our_buffer = 0;
	b->yy_input_file = 0;
	b->yy_n_chars = b->yy_buf_size;
	b->yy_is_interactive = 0;
	b->yy_at_bol = 1;
	b->yy_fill_buffer = 0;
	b->yy_buffer_status = YY_BUFFER_NEW;

	yy_switch_to_buffer(b  );

	return b;
}

/** Setup the input buffer state to scan a string. The next call to yylex() will
 * scan from a @e copy of @a str.
 * @param yystr a NUL-terminated string to scan
 * 
 * @return the newly allocated buffer state object.
 * @note If you want to scan bytes that may contain NUL values, then use
 *       yy_scan_bytes() instead.
 */
YY_BUFFER_STATE yy_scan_string (yyconst char * yystr )
{
    
	return yy_scan_bytes(yystr,strlen(yystr) );
}

/** Setup the input buffer state to scan the given bytes. The next call to yylex() will
 * scan from a @e copy of @a bytes.
 * @param bytes the byte buffer to scan
 * @param len the number of bytes in the buffer pointed to by @a bytes.
 * 
 * @return the newly allocated buffer state object.
 */
YY_BUFFER_STATE yy_scan_bytes  (yyconst char * yybytes, yy_size_t  _yybytes_len )
{
	YY_BUFFER_STATE b;
	char *buf;
	yy_size_t n, i;
    
	/* Get memory for full buffer, including space for trailing EOB's. */
	n = _yybytes_len + 2;
	buf = (char *) yyalloc(n  );
	if ( ! buf )
		YY_FATAL_ERROR( "out of dynamic memory in yy_scan_bytes()" );

	for ( i = 0; i < _yybytes_len; ++i )
		buf[i] = yybytes[i];

	buf[_yybytes_len] = buf[_yybytes_len+1] = YY_END_OF_BUFFER_CHAR;

	b = yy_scan_buffer(buf,n );
	if ( ! b )
		YY_FATAL_ERROR( "bad buffer in yy_scan_bytes()" );

	/* It's okay to grow etc. this buffer, and we should throw it
	 * away when we're done.
	 */
	b->yy_is_our_buffer = 1;

	return b;
}

#ifndef YY_EXIT_FAILURE
#define YY_EXIT_FAILURE 2
#endif

static void yy_fatal_error (yyconst char* msg )
{
    	(void) fprintf( stderr, "%s\n", msg );
	exit( YY_EXIT_FAILURE );
}

/* Redefine yyless() so it works in section 3 code. */

#undef yyless
#define yyless(n) \
	do \
		{ \
		/* Undo effects of setting up yytext. */ \
        int yyless_macro_arg = (n); \
        YY_LESS_LINENO(yyless_macro_arg);\
		yytext[yyleng] = (yy_hold_char); \
		(yy_c_buf_p) = yytext + yyless_macro_arg; \
		(yy_hold_char) = *(yy_c_buf_p); \
		*(yy_c_buf_p) = '\0'; \
		yyleng = yyless_macro_arg; \
		} \
	while ( 0 )

/* Accessor  methods (get/set functions) to struct members. */

/** Get the current line number.
 * 
 */
int yyget_lineno  (void)
{
        
    return yylineno;
}

/** Get the input stream.
 * 
 */
FILE *yyget_in  (void)
{
        return yyin;
}

/** Get the output stream.
 * 
 */
FILE *yyget_out  (void)
{
        return yyout;
}

/** Get the length of the current token.
 * 
 */
yy_size_t yyget_leng  (void)
{
        return yyleng;
}

/** Get the current token.
 * 
 */

char *yyget_text  (void)
{
        return yytext;
}

/** Set the current line number.
 * @param line_number
 * 
 */
void yyset_lineno (int  line_number )
{
    
    yylineno = line_number;
}

/** Set the input stream. This does not discard the current
 * input buffer.
 * @param in_str A readable stream.
 * 
 * @see yy_switch_to_buffer
 */
void yyset_in (FILE *  in_str )
{
        yyin = in_str ;
}

void yyset_out (FILE *  out_str )
{
        yyout = out_str ;
}

int yyget_debug  (void)
{
        return yy_flex_debug;
}

void yyset_debug (int  bdebug )
{
        yy_flex_debug = bdebug ;
}

static int yy_init_globals (void)
{
        /* Initialization is the same as for the non-reentrant scanner.
     * This function is called from yylex_destroy(), so don't allocate here.
     */

    (yy_buffer_stack) = 0;
    (yy_buffer_stack_top) = 0;
    (yy_buffer_stack_max) = 0;
    (yy_c_buf_p) = (char *) 0;
    (yy_init) = 0;
    (yy_start) = 0;

/* Defined in main.c */
#ifdef YY_STDINIT
    yyin = stdin;
    yyout = stdout;
#else
    yyin = (FILE *) 0;
    yyout = (FILE *) 0;
#endif

    /* For future reference: Set errno on error, since we are called by
     * yylex_init()
     */
    return 0;
}

/* yylex_destroy is for both reentrant and non-reentrant scanners. */
int yylex_destroy  (void)
{
    
    /* Pop the buffer stack, destroying each element. */
	while(YY_CURRENT_BUFFER){
		yy_delete_buffer(YY_CURRENT_BUFFER  );
		YY_CURRENT_BUFFER_LVALUE = NULL;
		yypop_buffer_state();
	}

	/* Destroy the stack itself. */
	yyfree((yy_buffer_stack) );
	(yy_buffer_stack) = NULL;

    /* Reset the globals. This is important in a non-reentrant scanner so the next time
     * yylex() is called, initialization will occur. */
    yy_init_globals( );

    return 0;
}

/*
 * Internal utility routines.
 */

#ifndef yytext_ptr
static void yy_flex_strncpy (char* s1, yyconst char * s2, int n )
{
	register int i;
	for ( i = 0; i < n; ++i )
		s1[i] = s2[i];
}
#endif

#ifdef YY_NEED_STRLEN
static int yy_flex_strlen (yyconst char * s )
{
	register int n;
	for ( n = 0; s[n]; ++n )
		;

	return n;
}
#endif

void *yyalloc (yy_size_t  size )
{
	return (void *) malloc( size );
}

void *yyrealloc  (void * ptr, yy_size_t  size )
{
	/* The cast to (char *) in the following accommodates both
	 * implementations that use char* generic pointers, and those
	 * that use void* generic pointers.  It works with the latter
	 * because both ANSI C and C++ allow castless assignment from
	 * any pointer type to void*, and deal with argument conversions
	 * as though doing an assignment.
	 */
	return (void *) realloc( (char *) ptr, size );
}

void yyfree (void * ptr )
{
	free( (char *) ptr );	/* see yyrealloc() for (char *) cast */
}

#define YYTABLES_NAME "yytables"

#line 396 "/Users/kenh/nmh/sbr/dtimep.l"


/* This is a portable way to squash a warning about the yyunput()
 * function being static but never used. It costs us a tiny amount
 * of extra code in the binary but the other options are:
 *  "%option nounput" which is flex-specific
 *  makefile hackery just to compile dtimep.c with different flags
 */
void dtimep_yyunput(int c)
{
    unput(c);
}


